==> classpath-0.16.tar.gz: classpath-0.16/org/omg/CosNaming/NamingContextPackage/NotFoundReasonHolder.java <==
/* NotFoundReasonHolder.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.CosNaming.NamingContextPackage;

import org.omg.CORBA.TypeCode;
import org.omg.CORBA.portable.InputStream;
import org.omg.CORBA.portable.OutputStream;
import org.omg.CORBA.portable.Streamable;

/**
* The holder for class {@link NotFoundReason}.
*
* @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
*/
public final class NotFoundReasonHolder
  implements Streamable
{
  /**
   * The stored value.
   */
  public NotFoundReason value;

  /**
   * Create the holder with unitialized value.
   */
  public NotFoundReasonHolder()
  {
  }

  /**
   * Create the holder, storing the given intial value.
   */
  public NotFoundReasonHolder(NotFoundReason initialValue)
  {
    value = initialValue;
  }

  /**
   * Read the holder from the CDR input stream.
   */
  public void _read(InputStream in)
  {
    value = NotFoundReasonHelper.read(in);
  }

  /**
   * Get the type code of {@link NotFoundReason}.
   * @return
   */
  public TypeCode _type()
  {
    return NotFoundReasonHelper.type();
  }

  /**
   * Write the holder to the CDR output stream.
   */
  public void _write(OutputStream out)
  {
    NotFoundReasonHelper.write(out, value);
  }
}

==> classpath-0.93.tar.gz: classpath-0.93/org/omg/CosNaming/NamingContextPackage/NotFoundReasonHolder.java <==
/* NotFoundReasonHolder.java --
   Copyright (C) 2005, 2006 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.CosNaming.NamingContextPackage;

import org.omg.CORBA.TypeCode;
import org.omg.CORBA.portable.InputStream;
import org.omg.CORBA.portable.OutputStream;
import org.omg.CORBA.portable.Streamable;

/**
* The holder for class {@link NotFoundReason}.
*
* @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
*/
public final class NotFoundReasonHolder
  implements Streamable
{
  /**
   * The stored value.
   */
  public NotFoundReason value;

  /**
   * Create the holder with unitialized value.
   */
  public NotFoundReasonHolder()
  {
  }

  /**
   * Create the holder, storing the given intial value.
   */
  public NotFoundReasonHolder(NotFoundReason initialValue)
  {
    value = initialValue;
  }

  /**
   * Read the holder from the CDR input stream.
   */
  public void _read(InputStream in)
  {
    value = NotFoundReasonHelper.read(in);
  }

  /**
   * Get the type code of {@link NotFoundReason}.
   * 
   * @return the typecode of enumeration, allowed value names being
   *         "missing_node", "not_context" and "not_object"
   */
  public TypeCode _type()
  {
    return NotFoundReasonHelper.type();
  }

  /**
   * Write the holder to the CDR output stream.
   */
  public void _write(OutputStream out)
  {
    NotFoundReasonHelper.write(out, value);
  }
}
